@@ -39,23 +39,24 @@ typedef struct _GtkEntryCompletion            GtkEntryCompletion;
 
 /**
  * GtkEntryCompletionMatchFunc:
- * @completion: the #GtkEntryCompletion
+ * @completion: the `GtkEntryCompletion`
  * @key: the string to match, normalized and case-folded
- * @iter: a #GtkTreeIter indicating the row to match
+ * @iter: a `GtkTreeIter` indicating the row to match
  * @user_data: user data given to gtk_entry_completion_set_match_func()
  *
  * A function which decides whether the row indicated by @iter matches
  * a given @key, and should be displayed as a possible completion for @key.
+ *
  * Note that @key is normalized and case-folded (see g_utf8_normalize()
  * and g_utf8_casefold()). If this is not appropriate, match functions
  * have access to the unmodified key via
  * `gtk_editable_get_text (GTK_EDITABLE (gtk_entry_completion_get_entry ()))`.
  *
  * Returns: %TRUE if @iter should be displayed as a possible completion
- *     for @key
+ *   for @key
  */
 typedef gboolean (* GtkEntryCompletionMatchFunc) (GtkEntryCompletion *completion,
-                                                  const gchar        *key,
+                                                  const char         *key,
                                                   GtkTreeIter        *iter,
                                                   gpointer            user_data);
 
@@ -83,29 +84,17 @@ void                gtk_entry_completion_set_match_func         (GtkEntryComplet
                                                                  GDestroyNotify               func_notify);
 GDK_AVAILABLE_IN_ALL
 void                gtk_entry_completion_set_minimum_key_length (GtkEntryCompletion          *completion,
-                                                                 gint                         length);
+                                                                 int                          length);
 GDK_AVAILABLE_IN_ALL
-gint                gtk_entry_completion_get_minimum_key_length (GtkEntryCompletion          *completion);
+int                 gtk_entry_completion_get_minimum_key_length (GtkEntryCompletion          *completion);
 GDK_AVAILABLE_IN_ALL
-gchar *             gtk_entry_completion_compute_prefix         (GtkEntryCompletion          *completion,
+char *             gtk_entry_completion_compute_prefix         (GtkEntryCompletion          *completion,
                                                                  const char                  *key);
 GDK_AVAILABLE_IN_ALL
 void                gtk_entry_completion_complete               (GtkEntryCompletion          *completion);
 GDK_AVAILABLE_IN_ALL
 void                gtk_entry_completion_insert_prefix          (GtkEntryCompletion          *completion);
 
-GDK_AVAILABLE_IN_ALL
-void                gtk_entry_completion_insert_action_text     (GtkEntryCompletion          *completion,
-                                                                 gint                         index_,
-                                                                 const gchar                 *text);
-GDK_AVAILABLE_IN_ALL
-void                gtk_entry_completion_insert_action_markup   (GtkEntryCompletion          *completion,
-                                                                 gint                         index_,
-                                                                 const gchar                 *markup);
-GDK_AVAILABLE_IN_ALL
-void                gtk_entry_completion_delete_action          (GtkEntryCompletion          *completion,
-                                                                 gint                         index_);
-
 GDK_AVAILABLE_IN_ALL
 void                gtk_entry_completion_set_inline_completion  (GtkEntryCompletion          *completion,
                                                                  gboolean                     inline_completion);
@@ -133,13 +122,13 @@ GDK_AVAILABLE_IN_ALL
 gboolean            gtk_entry_completion_get_popup_single_match (GtkEntryCompletion          *completion);
 
 GDK_AVAILABLE_IN_ALL
-const gchar         *gtk_entry_completion_get_completion_prefix (GtkEntryCompletion *completion);
+const char          *gtk_entry_completion_get_completion_prefix (GtkEntryCompletion *completion);
 /* convenience */
 GDK_AVAILABLE_IN_ALL
 void                gtk_entry_completion_set_text_column        (GtkEntryCompletion          *completion,
-                                                                 gint                         column);
+                                                                 int                          column);
 GDK_AVAILABLE_IN_ALL
-gint                gtk_entry_completion_get_text_column        (GtkEntryCompletion          *completion);
+int                 gtk_entry_completion_get_text_column        (GtkEntryCompletion          *completion);
 
 G_END_DECLS
 
